﻿from django.shortcuts import render_to_response
from django.template import RequestContext
from django.contrib import admin
from django.utils.translation import ugettext_lazy, ugettext as _
import datetime

from hsis.mymodels.models import *

classAdmin = admin.ModelAdmin(Class, admin.site)
courseAdmin = admin.ModelAdmin(Course, admin.site)
studentAdmin = admin.ModelAdmin(Student, admin.site)
teacherAdmin = admin.ModelAdmin(Teacher, admin.site)

def custom_proc(request):
    "A context processor that provides 'user', and 'ip_address'."
    return {
        'user': request.user,
        'ip_address': request.META['REMOTE_ADDR']
    }

def requires_login(view):
    def new_view(request, *args, **kwargs):
        if not request.user.is_authenticated():
            return admin.site.login(request)
        return view(request, *args, **kwargs)
    return new_view

def courses_list(request):
	user = request.user
	return render_to_response('admin/ManagerAction/courses_list.html', 
		{'courses': Course.objects.all()}, 
		context_instance=RequestContext(request, processors=[custom_proc])
	)
	
def add_course(request):
	global courseAdmin
	courseAdmin.add_form_template = "admin/ManagerAction/change_form.html"
	return courseAdmin.add_view(request, 
		extra_context = {'mytitle' : 'Xin hãy điền đầy đủ thông tin về khóa học:'})
		
def add_class(request, year):
	global classAdmin
	classAdmin.add_form_template = "admin/ManagerAction/change_form.html"
	return classAdmin.add_view(request, 
		extra_context = {'mytitle' : 'Xin hãy điền đầy đủ thông tin về lớp học:'})
		
def add_student(request, year, classID):
	global studentAdmin
	studentAdmin.add_form_template = "admin/ManagerAction/change_form.html"
	return studentAdmin.add_view(request, 
		extra_context = {'mytitle' : 'Xin hãy điền đầy đủ thông tin về học sinh:'})
		
def add_teacher(request):
	global teacherAdmin
	teacherAdmin.add_form_template = "admin/ManagerAction/change_form.html"
	return teacherAdmin.add_view(request, 
		extra_context = {'mytitle' : 'Xin hãy điền đầy đủ thông tin về giáo viên:'})
		
def edit_course(request, year):
	c = Course.objects.get(startingYear = year)
	global courseAdmin
	courseAdmin.change_form_template = "admin/ManagerAction/change_form.html"
	return courseAdmin.change_view(request, str(c.course_id), 
		extra_context = {'mytitle' : 'Sửa thông tin khóa học:'})

def classes_list(request, year):
	c = Course.objects.get(startingYear = int(year))
	global courseAdmin
	courseAdmin.change_form_template = "admin/ManagerAction/classes_list.html"
	return courseAdmin.change_view(request, str(c.course_id))
	
def students_list(request, y, classID):
	co = Course.objects.get(startingYear = int(y))
	cl = Class.objects.get(class_id = classID)
	now = datetime.datetime.now()
	if (now.month >= 9):
		classNumber = now.year - int(y) + 1 + 10
	else:
		classNumber = now.year - int(y) + 10
	global classAdmin
	classAdmin.change_form_template = "admin/ManagerAction/students_list.html"
	return classAdmin.change_view(request, str(cl.class_id), 
		{'courseYear': y, 'classNumber': classNumber})
		
def edit_student(request, y, classID, studentID):
	global studentAdmin
	studentAdmin.change_form_template = "admin/ManagerAction/change_form.html"
	return studentAdmin.change_view(request, str(studentID), 
		extra_context = {'mytitle' : 'Sửa thông tin học sinh:'})

def teachers_list(request):
	user = request.user
	return render_to_response('admin/ManagerAction/teachers_list.html', 
		{'teachers': Teacher.objects.all()}, 
		context_instance=RequestContext(request, processors=[custom_proc])
	)
	
def edit_teacher(request, teacherID):
	global teacherAdmin
	teacherAdmin.change_form_template = "admin/ManagerAction/change_form.html"
	return teacherAdmin.change_view(request, str(teacherID), 
		extra_context = {'mytitle' : 'Sửa thông tin giáo viên:'})
	

